ProSHADE: Member List

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup Member List

This is the complete list of members for ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup, including all inherited members.

angularDistanceWithBorders(proshade_signed origLat, proshade_signed testedLat) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup | protected
checkIfPeakBelongs(proshade_double lat, proshade_double lon, proshade_unsign sphPos, proshade_double cosTol, proshade_signed verbose) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
computeCornerPositions(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup | protected
dimension (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
findCyclicPointGroupsGivenFold(std::vector< ProSHADE_internal_spheres::ProSHADE_rotFun_sphere * > sphereVals, proshade_double axisTolerance, std::vector< proshade_double * > *detectedCs, bool bicubicInterp, proshade_unsign fold, proshade_unsign verbose) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
getAllAngleDifferences(std::vector< proshade_double > *angDiffs, std::vector< ProSHADE_internal_spheres::ProSHADE_rotFun_sphere * > sphereVals) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup | protected
getAllPossibleFolds(std::vector< proshade_double > *angDiffs, std::vector< proshade_unsign > *foldsToTry, std::vector< ProSHADE_internal_spheres::ProSHADE_rotFun_sphere * > sphereVals) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup | protected
getBestIndexForFold(proshade_double *bestPosVal, proshade_double *bestLatInd, proshade_double *bestLonInd, std::vector< proshade_unsign > *spheresFormingFold, std::vector< ProSHADE_internal_spheres::ProSHADE_rotFun_sphere * > sphereVals) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup | protected
getLatFromIndices(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
getLatToIndices(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
getLonFromIndices(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
getLonToIndices(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
getSpherePositions(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
getSpheresFormingFold(proshade_unsign foldToTry, std::vector< proshade_unsign > *spheresFormingFold, std::vector< ProSHADE_internal_spheres::ProSHADE_rotFun_sphere * > sphereVals, proshade_double sphereAngleTolerance) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup | protected
latFrom (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
latFromInds (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
latMaxLonMaxXYZ (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
latMaxLonMinXYZ (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
latMinLonMaxXYZ (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
latMinLonMinXYZ (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
latSampling (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
latTo (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
latToInds (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
lonFrom (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
lonFromInds (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
lonSampling (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
lonTo (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
lonToInds (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
ProSHADE_rotFun_spherePeakGroup(proshade_double lat, proshade_double lon, proshade_unsign sphPos, proshade_unsign angDim) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
spherePositions (defined in ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |
~ProSHADE_rotFun_spherePeakGroup(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup |